@@ -76,7 +76,7 @@ typedef struct cm_buf {
     afs_uint32 waitRequests;    /* num of thread wait requests */
 
     afs_uint32 dirty_offset;    /* offset from beginning of buffer containing dirty bytes */
-    afs_uint32 dirty_length;    /* number of dirty bytes within the buffer */
+    afs_uint32 dirty_length;      /* number of dirty bytes within the buffer */
 
 #ifdef DISKCACHE95
     cm_diskcache_t *dcp;        /* diskcache structure */
@@ -154,11 +154,15 @@ extern cm_buf_t *buf_FindLocked(struct cm_scache *, osi_hyper_t *);
 
 extern cm_buf_t *buf_Find(struct cm_scache *, osi_hyper_t *);
 
-extern long buf_GetNewLocked(struct cm_scache *, osi_hyper_t *, cm_buf_t **);
+extern cm_buf_t *buf_FindAllLocked(struct cm_scache *, osi_hyper_t *, afs_uint32 flags);
+ 
+extern cm_buf_t *buf_FindAll(struct cm_scache *, osi_hyper_t *, afs_uint32 flags);
+ 
+extern long buf_GetNewLocked(struct cm_scache *, osi_hyper_t *, cm_req_t *, cm_buf_t **);
 
-extern long buf_Get(struct cm_scache *, osi_hyper_t *, cm_buf_t **);
+extern long buf_Get(struct cm_scache *, osi_hyper_t *, cm_req_t *, cm_buf_t **);
 
-extern long buf_GetNew(struct cm_scache *, osi_hyper_t *, cm_buf_t **);
+extern long buf_GetNew(struct cm_scache *, osi_hyper_t *, cm_req_t *, cm_buf_t **);
 
 extern afs_uint32 buf_CleanAsyncLocked(cm_buf_t *, cm_req_t *, afs_uint32 *);
 
