@@ -45,7 +45,8 @@ int cm_bkgWaitingForCount;	/* true if someone's waiting for cm_bkgQueueCount to
 cm_bkgRequest_t *cm_bkgListp;		/* first elt in the list of requests */
 cm_bkgRequest_t *cm_bkgListEndp;	/* last elt in the list of requests */
 
-static int daemon_ShutdownFlag = 0;
+extern int powerStateSuspended;
+int daemon_ShutdownFlag = 0;
 static int cm_nDaemons = 0;
 static time_t lastIPAddrChange = 0;
 
@@ -98,6 +99,10 @@ void cm_BkgDaemon(void * parm)
 
     lock_ObtainWrite(&cm_daemonLock);
     while (daemon_ShutdownFlag == 0) {
+        if (powerStateSuspended) {
+            Sleep(1000);
+            continue;
+        }
         if (!cm_bkgListEndp) {
             osi_SleepW((LONG_PTR)&cm_bkgListp, &cm_daemonLock);
             lock_ObtainWrite(&cm_daemonLock);
@@ -406,6 +411,10 @@ void cm_Daemon(long parm)
         lastPerformanceCheck = now - cm_daemonPerformanceTuningInterval/2 * (rand() % cm_daemonPerformanceTuningInterval);
 
     while (daemon_ShutdownFlag == 0) {
+        if (powerStateSuspended) {
+            Sleep(1000);
+            continue;
+        }
 	/* check to see if the listener threads halted due to network 
 	 * disconnect or other issues.  If so, attempt to restart them.
 	 */
@@ -449,7 +458,8 @@ void cm_Daemon(long parm)
 
         /* check down servers */
         if ((bAddrChangeCheck || now > lastDownServerCheck + cm_daemonCheckDownInterval) &&
-            daemon_ShutdownFlag == 0) {
+            daemon_ShutdownFlag == 0 &&
+            powerStateSuspended == 0) {
             lastDownServerCheck = now;
 	    osi_Log0(afsd_logp, "cm_Daemon CheckDownServers");
             cm_CheckServers(CM_FLAG_CHECKDOWNSERVERS, NULL);
@@ -458,12 +468,15 @@ void cm_Daemon(long parm)
 	    now = osi_Time();
         }
 
-        if (bAddrChangeCheck)
+        if (bAddrChangeCheck &&
+            daemon_ShutdownFlag == 0 &&
+            powerStateSuspended == 0)
             cm_ForceNewConnectionsAllServers();
 
         /* check up servers */
         if ((bAddrChangeCheck || now > lastUpServerCheck + cm_daemonCheckUpInterval) &&
-            daemon_ShutdownFlag == 0) {
+            daemon_ShutdownFlag == 0 &&
+            powerStateSuspended == 0) {
             lastUpServerCheck = now;
 	    osi_Log0(afsd_logp, "cm_Daemon CheckUpServers");
             cm_CheckServers(CM_FLAG_CHECKUPSERVERS, NULL);
@@ -472,13 +485,16 @@ void cm_Daemon(long parm)
 	    now = osi_Time();
         }
 
-        if (bAddrChangeCheck) {
+        if (bAddrChangeCheck &&
+            daemon_ShutdownFlag == 0 &&
+            powerStateSuspended == 0) {
             smb_CheckVCs();
             cm_VolStatus_Network_Addr_Change();
         }
 
         if (now > lastVolCheck + cm_daemonCheckVolInterval &&
-            daemon_ShutdownFlag == 0) {
+            daemon_ShutdownFlag == 0 &&
+            powerStateSuspended == 0) {
             lastVolCheck = now;
             cm_RefreshVolumes();
             if (daemon_ShutdownFlag == 1)
@@ -488,7 +504,8 @@ void cm_Daemon(long parm)
 
         if (cm_daemonCheckVolCBInterval && 
             now > lastVolCBRenewalCheck + cm_daemonCheckVolCBInterval &&
-            daemon_ShutdownFlag == 0) {
+            daemon_ShutdownFlag == 0 &&
+            powerStateSuspended == 0) {
             lastVolCBRenewalCheck = now;
             cm_VolumeRenewROCallbacks();
             if (daemon_ShutdownFlag == 1)
@@ -497,7 +514,8 @@ void cm_Daemon(long parm)
         }
 
         if ((bAddrChangeCheck || now > lastBusyVolCheck + cm_daemonCheckOfflineVolInterval) &&
-            daemon_ShutdownFlag == 0) {
+            daemon_ShutdownFlag == 0 &&
+            powerStateSuspended == 0) {
             lastVolCheck = now;
             cm_CheckOfflineVolumes();
             if (daemon_ShutdownFlag == 1)
@@ -506,7 +524,8 @@ void cm_Daemon(long parm)
         }
 
         if (now > lastCBExpirationCheck + cm_daemonCheckCBInterval &&
-            daemon_ShutdownFlag == 0) {
+            daemon_ShutdownFlag == 0 &&
+            powerStateSuspended == 0) {
             lastCBExpirationCheck = now;
             cm_CheckCBExpiration();
             if (daemon_ShutdownFlag == 1)
@@ -515,7 +534,8 @@ void cm_Daemon(long parm)
         }
 
         if (now > lastLockCheck + cm_daemonCheckLockInterval &&
-            daemon_ShutdownFlag == 0) {
+            daemon_ShutdownFlag == 0 &&
+            powerStateSuspended == 0) {
             lastLockCheck = now;
             cm_CheckLocks();
             if (daemon_ShutdownFlag == 1)
@@ -524,7 +544,8 @@ void cm_Daemon(long parm)
         }
 
         if (now > lastTokenCacheCheck + cm_daemonTokenCheckInterval &&
-            daemon_ShutdownFlag == 0) {
+            daemon_ShutdownFlag == 0 &&
+            powerStateSuspended == 0) {
             lastTokenCacheCheck = now;
             cm_CheckTokenCache(now);
             if (daemon_ShutdownFlag == 1)
@@ -533,7 +554,7 @@ void cm_Daemon(long parm)
         }
 
         /* allow an exit to be called prior to stopping the service */
-        hHookDll = LoadLibrary(AFSD_HOOK_DLL);
+        hHookDll = cm_LoadAfsdHookLib();
         if (hHookDll)
         {
             BOOL hookRc = TRUE;
@@ -549,15 +570,17 @@ void cm_Daemon(long parm)
             {
                 SetEvent(WaitToTerminate);
             }
-        }
 
-        if (daemon_ShutdownFlag == 1) {
-            break;
+            if (daemon_ShutdownFlag == 1) {
+                break;
+            }
+	    now = osi_Time();
         }
 
         if (cm_daemonPerformanceTuningInterval &&
             now > lastPerformanceCheck + cm_daemonPerformanceTuningInterval &&
-             daemon_ShutdownFlag == 0) {
+            daemon_ShutdownFlag == 0 &&
+            powerStateSuspended == 0) {
             lastPerformanceCheck = now;
             cm_PerformanceTuningCheck();
             if (daemon_ShutdownFlag == 1)
