@@ -21,8 +21,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_symlink.c,v 1.24.4.13 2009/05/11 13:29:21 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -70,7 +68,7 @@ afs_DisconCreateSymlink(struct vcache *avc, char *aname,
 /* don't set CDirty in here because RPC is called synchronously */
 int 
 afs_symlink(OSI_VC_DECL(adp), char *aname, struct vattr *attrs, 
-	    char *atargetName, struct AFS_UCRED *acred)
+	    char *atargetName, AFS_UCRED *acred)
 {
     afs_uint32 now = 0;
     struct vrequest treq;
@@ -406,7 +404,7 @@ afs_UFSHandleLink(register struct vcache *avc, struct vrequest *areq)
 }
 
 int
-afs_readlink(OSI_VC_DECL(avc), struct uio *auio, struct AFS_UCRED *acred)
+afs_readlink(OSI_VC_DECL(avc), struct uio *auio, AFS_UCRED *acred)
 {
     register afs_int32 code;
     struct vrequest treq;
