@@ -18,6 +18,14 @@
 #include "afs/afs_args.h"
 #endif
 
+/*
+ * afs_fsfragsize cannot be less than 1023, or some cache-tracking
+ * calculations will be incorrect (since we track cache usage in kb).
+ * Some filesystems have fundamental blocksizes less than 1k, and
+ * normally we would tune afs_fsfragsize to be fragsize-1, but we must
+ * make sure to check that afs_fsfragsize does not go below this value.
+ */
+#define AFS_MIN_FRAGSIZE 1023
 
 /* Upper bound on number of iovecs out uio routines will deal with. */
 #define	AFS_MAXIOVCNT	    16
@@ -138,7 +146,7 @@ struct sysname_info {
 #define	BUWAIT		4	/* someone is waiting for BUVALID */
 struct brequest {
     struct vcache *vc;		/* vnode to use, with vrefcount bumped */
-    struct AFS_UCRED *cred;	/* credentials to use for operation */
+    AFS_UCRED *cred;	/* credentials to use for operation */
     afs_size_t size_parm[BPARMS];	/* random parameters */
     void *ptr_parm[BPARMS];	/* pointer parameters */
     afs_int32 code;		/* return code */
@@ -842,7 +850,7 @@ struct vcache {
 #endif				/* AFS_SGI_ENV */
     afs_int32 vc_error;		/* stash write error for this vnode. */
     int xlatordv;		/* Used by nfs xlator */
-    struct AFS_UCRED *uncred;
+    AFS_UCRED *uncred;
     int asynchrony;		/* num kbytes to store behind */
 #ifdef AFS_SUN5_ENV
     short multiPage;		/* count of multi-page getpages in progress */
@@ -982,9 +990,15 @@ struct cm_initparams {
 #define	IFAnyPages	32
 #define	IFDiscarded	64	/* index entry in discardDCList */
 
+#ifdef AFS_DARWIN100_ENV
+typedef user_addr_t iparmtype; /* 64 bit */
+#else
+typedef char * iparmtype;
+#endif
+
 struct afs_ioctl {
-    char *in;			/* input buffer */
-    char *out;			/* output buffer */
+    iparmtype in;		/* input buffer */
+    iparmtype out;		/* output buffer */
     short in_size;		/* Size of input buffer <= 2K */
     short out_size;		/* Maximum size of output buffer, <= 2K */
 };
@@ -1139,6 +1153,12 @@ struct memCacheEntry {
   char *data;                 /* bytes */
 };
 
+struct afs_FetchOutput {
+    struct AFSVolSync tsync;
+    struct AFSFetchStatus OutStatus;
+    struct AFSCallBack CallBack;
+};
+
 /* macro to mark a dcache entry as bad */
 #define ZapDCE(x) \
     do { \
@@ -1348,6 +1368,28 @@ extern struct brequest afs_brs[NBRS];	/* request structures */
 struct buf;
 #endif
 
+struct storeOps {
+    int (*prepare)(void *rock, afs_uint32 size, afs_uint32 *bytestoxfer);
+    int (*read)(void *rock, struct osi_file *tfile, afs_uint32 offset,
+        afs_uint32 tlen, afs_uint32 *bytesread);
+    int (*write)(void *rock, afs_uint32 tlen, afs_uint32 *byteswritten);
+    int (*status)(void *rock);
+    int (*padd)(void *rock, afs_uint32 tlen);
+    int (*close)(void *rock, struct AFSFetchStatus *OutStatus,
+        afs_int32 *doProcessFS);
+    int (*destroy)(void **rock, afs_int32 error);
+};
+
+struct fetchOps {
+    int (*more)(void *rock, afs_uint32 *length, afs_uint32 *moredata);
+    int (*read)(void *rock, afs_uint32 tlen, afs_uint32 *bytesread);
+    int (*write)(void *rock, struct osi_file *fp, afs_uint32 offset,
+        afs_uint32 tlen, afs_uint32 *byteswritten);
+    int (*close)(void *rock, struct vcache *avc, struct dcache *adc,
+        struct afs_FetchOutput *Outputs);
+    int (*destroy)(void **rock, afs_int32 error);
+};
+
 /* fakestat support: opaque storage for afs_EvalFakeStat to remember
  * what vcache should be released.
  */
