@@ -108,7 +108,7 @@ rxfs_storeMemPrepare(void *r, afs_uint32 size, afs_uint32 *tlen)
     RX_AFS_GLOCK();
     if (code <= 0) {
 	code = rx_Error(v->call);
-	if ( !code )
+	if (!code)
 	    code = -33;
     }
     else {
@@ -196,14 +196,14 @@ afs_int32
 rxfs_storePadd(void *rock, afs_uint32 size)
 {
     afs_int32 code = 0;
-    int bsent, tlen;
+    afs_uint32 tlen;
     struct rxfs_storeVariables *v = (struct rxfs_storeVariables *)rock;
 
-    if ( !v->tbuffer )
+    if (!v->tbuffer)
 	v->tbuffer = osi_AllocLargeSpace(AFS_LRALLOCSIZ);
     memset(v->tbuffer, 0, AFS_LRALLOCSIZ);
 
-    while (size > 0) {
+    while (size) {
 	tlen = (size > AFS_LRALLOCSIZ ? AFS_LRALLOCSIZ : size);
 	RX_AFS_GUNLOCK();
 	code = rx_Write(v->call, v->tbuffer, tlen);
@@ -233,8 +233,15 @@ rxfs_storeClose(void *r, struct AFSFetchStatus *OutStatus, int *doProcessFS)
     struct AFSVolSync tsync;
     struct rxfs_storeVariables *v = (struct rxfs_storeVariables *)r;
 
+    if (!v->call)
+	return -1;
     RX_AFS_GUNLOCK();
-    code = EndRXAFS_StoreData(v->call, OutStatus, &tsync);
+#ifdef AFS_64BIT_CLIENT
+    if (!v->hasNo64bit)
+	code = EndRXAFS_StoreData64(v->call, OutStatus, &tsync);
+    else
+#endif
+	code = EndRXAFS_StoreData(v->call, OutStatus, &tsync);
     RX_AFS_GLOCK();
     if (!code)
 	*doProcessFS = 1;	/* Flag to run afs_ProcessFS() later on */
@@ -250,12 +257,11 @@ rxfs_storeDestroy(void **r, afs_int32 error)
 
     *r = NULL;
     if (v->call) {
-	afs_int32 code2;
 	RX_AFS_GUNLOCK();
-	code2 = rx_EndCall(v->call, code);
+	code = rx_EndCall(v->call, error);
 	RX_AFS_GLOCK();
-	if (code2)
-	    code = code2;
+	if (!code && error)
+	    code = error;
     }
     if (v->tbuffer)
 	osi_FreeLargeSpace(v->tbuffer);
@@ -288,8 +294,8 @@ struct storeOps rxfs_storeMemOps = {
 };
 
 afs_int32
-rxfs_storeInit(struct vcache *avc, struct afs_conn *tc, afs_size_t tlen,
-		afs_size_t bytes, afs_size_t base,
+rxfs_storeInit(struct vcache *avc, struct afs_conn *tc, afs_size_t base,
+		afs_size_t bytes, afs_size_t length,
 		int sync, struct storeOps **ops, void **rock)
 {
     afs_int32 code;
@@ -312,20 +318,21 @@ rxfs_storeInit(struct vcache *avc, struct afs_conn *tc, afs_size_t tlen,
     if (v->call) {
 #ifdef AFS_64BIT_CLIENT
 	if (!afs_serverHasNo64Bit(tc))
-	    code = StartRXAFS_StoreData64(v->call,(struct AFSFid*)&avc->f.fid.Fid,
-				       &v->InStatus, base, bytes, tlen);
+	    code = StartRXAFS_StoreData64(
+	    			v->call, (struct AFSFid*)&avc->f.fid.Fid,
+				&v->InStatus, base, bytes, length);
 	else
-	    if (tlen > 0xFFFFFFFF)
+	    if (length > 0xFFFFFFFF)
 		code = EFBIG;
 	    else {
-		afs_int32 t1 = base, t2 = bytes, t3 = tlen;
+		afs_int32 t1 = base, t2 = bytes, t3 = length;
 		code = StartRXAFS_StoreData(v->call,
 					(struct AFSFid *) &avc->f.fid.Fid,
 					 &v->InStatus, t1, t2, t3);
 	    }
 #else /* AFS_64BIT_CLIENT */
 	code = StartRXAFS_StoreData(v->call, (struct AFSFid *)&avc->f.fid.Fid,
-				    &v->InStatus, base, bytes, tlen);
+				    &v->InStatus, base, bytes, length);
 #endif /* AFS_64BIT_CLIENT */
     } else
 	code = -1;
@@ -351,9 +358,9 @@ rxfs_storeInit(struct vcache *avc, struct afs_conn *tc, afs_size_t tlen,
 	/* for now, only do 'continue from close' code if file fits in one
 	 * chunk.  Could clearly do better: if only one modified chunk
 	 * then can still do this.  can do this on *last* modified chunk */
-	tlen = avc->f.m.Length - 1;	/* byte position of last byte we'll store */
+	length = avc->f.m.Length - 1; /* byte position of last byte we'll store */
 	if (shouldWake) {
-	    if (AFS_CHUNK(tlen) != 0)
+	    if (AFS_CHUNK(length) != 0)
 		*shouldWake = 0;
 	    else
 		*shouldWake = 1;
@@ -403,10 +410,10 @@ afs_CacheStoreDCaches(struct vcache *avc, struct dcache **dclist,
 
     for (i = 0; i < nchunks && !code; i++) {
 	int stored = 0;
-	struct osi_file *fP;
+	struct osi_file *tfile;
 	int offset = 0;
 	struct dcache *tdc = dclist[i];
-	afs_int32 alen = tdc->f.chunkBytes;
+	afs_int32 size = tdc->f.chunkBytes;
 	if (!tdc) {
 	    afs_warn("afs: missing dcache!\n");
 	    storeallmissing++;
@@ -424,11 +431,11 @@ afs_CacheStoreDCaches(struct vcache *avc, struct dcache **dclist,
 	    else if ((afs_uint32) avc->asynchrony >= (bytes - stored))
 		shouldwake = &nomore;
 	}
-	fP = afs_CFileOpen(&tdc->f.inode);
+	tfile = afs_CFileOpen(&tdc->f.inode);
 
 	afs_Trace4(afs_iclSetp, CM_TRACE_STOREPROC, ICL_TYPE_POINTER, avc,
 		    ICL_TYPE_FID, &(avc->f.fid), ICL_TYPE_OFFSET,
-		    ICL_HANDLE_OFFSET(avc->f.m.Length), ICL_TYPE_INT32, alen);
+		    ICL_HANDLE_OFFSET(avc->f.m.Length), ICL_TYPE_INT32, size);
 
 	AFS_STATCNT(CacheStoreProc);
 
@@ -436,23 +443,23 @@ afs_CacheStoreDCaches(struct vcache *avc, struct dcache **dclist,
 	avc->f.truncPos = AFS_NOTRUNC;
 #ifndef AFS_NOSTATS
 	/*
-	 * In this case, alen is *always* the amount of data we'll be trying
+	 * In this case, size is *always* the amount of data we'll be trying
 	 * to ship here.
 	 */
-	bytesToXfer = alen;
+	bytesToXfer = size;
 	bytesXferred = 0;
 
 	osi_GetuTime(&xferStartTime);
 #endif /* AFS_NOSTATS */
 
-	while ( alen > 0 ) {
+	while ( size > 0 ) {
 	    afs_uint32 tlen;
 	    afs_int32 bytesread, byteswritten;
-	    code = (*ops->prepare)(rock, alen, &tlen);
+	    code = (*ops->prepare)(rock, size, &tlen);
 	    if ( code )
 		break;
 
-	    code = (*ops->read)(rock, fP, offset, tlen, &bytesread);
+	    code = (*ops->read)(rock, tfile, offset, tlen, &bytesread);
 	    if (code)
 		break;
 
@@ -465,7 +472,7 @@ afs_CacheStoreDCaches(struct vcache *avc, struct dcache **dclist,
 #endif /* AFS_NOSTATS */
 
 	    offset += tlen;
-	    alen -= tlen;
+	    size -= tlen;
 	    /*
 	     * if file has been locked on server, can allow
 	     * store to continue
@@ -477,34 +484,17 @@ afs_CacheStoreDCaches(struct vcache *avc, struct dcache **dclist,
 	}
 	afs_Trace4(afs_iclSetp, CM_TRACE_STOREPROC, ICL_TYPE_POINTER, avc,
 		    ICL_TYPE_FID, &(avc->f.fid), ICL_TYPE_OFFSET,
-		    ICL_HANDLE_OFFSET(avc->f.m.Length), ICL_TYPE_INT32, alen);
+		    ICL_HANDLE_OFFSET(avc->f.m.Length), ICL_TYPE_INT32, size);
 
 #ifndef AFS_NOSTATS
 	FillStoreStats(code, AFS_STATS_FS_XFERIDX_STOREDATA,
 		    &xferStartTime, bytesToXfer, bytesXferred);
 #endif /* AFS_NOSTATS */
 
-	afs_CFileClose(fP);
+	afs_CFileClose(tfile);
 	if ((tdc->f.chunkBytes < afs_OtherCSize)
 		&& (i < (nchunks - 1)) && code == 0) {
-	    int bsent, tlen, sbytes = afs_OtherCSize - tdc->f.chunkBytes;
-	    char *tbuffer = osi_AllocLargeSpace(AFS_LRALLOCSIZ);
-
-	    while (sbytes > 0) {
-		tlen = (sbytes > AFS_LRALLOCSIZ ? AFS_LRALLOCSIZ : sbytes);
-		memset(tbuffer, 0, tlen);
-		RX_AFS_GUNLOCK();
-		bsent = rx_Write(
-			((struct rxfs_storeVariables*)rock)->call, tbuffer, tlen);
-		RX_AFS_GLOCK();
-
-		if (bsent != tlen) {
-		    code = -33;	/* XXX */
-		    break;
-		}
-		sbytes -= tlen;
-	    }
-	    osi_FreeLargeSpace(tbuffer);
+	    code = (*ops->padd)(rock, afs_OtherCSize - tdc->f.chunkBytes);
 	}
 	stored += tdc->f.chunkBytes;
 	/* ideally, I'd like to unlock the dcache and turn
@@ -522,7 +512,8 @@ afs_CacheStoreDCaches(struct vcache *avc, struct dcache **dclist,
 	}
 	XSTATS_END_TIME;
     }
-    code = (*ops->destroy)(&rock, code);
+    if (ops)
+	code = (*ops->destroy)(&rock, code);
     return code;
 }
 
@@ -554,11 +545,9 @@ afs_CacheStoreVCache(struct dcache **dcList, struct vcache *avc,
     void * rock = NULL;
     unsigned int i, j;
 
-    struct AFSStoreStatus InStatus;
     struct AFSFetchStatus OutStatus;
     int doProcessFS = 0;
     afs_size_t base, bytes, length;
-    afs_uint32 nchunks;
     int nomore;
     unsigned int first = 0;
     struct afs_conn *tc;
@@ -577,6 +566,7 @@ afs_CacheStoreVCache(struct dcache **dcList, struct vcache *avc,
 	    }
 	}
 	if (bytes && (j == high || !dcList[j + 1])) {
+	    afs_uint32 nchunks;
 	    struct dcache **dclist = &dcList[first];
 	    /* base = AFS_CHUNKTOBASE(dcList[first]->f.chunk); */
 	    base = AFS_CHUNKTOBASE(first + minj);
@@ -603,28 +593,28 @@ afs_CacheStoreVCache(struct dcache **dcList, struct vcache *avc,
 		       ICL_HANDLE_OFFSET(base), ICL_TYPE_OFFSET,
 		       ICL_HANDLE_OFFSET(bytes), ICL_TYPE_OFFSET,
 		       ICL_HANDLE_OFFSET(length));
+	    tc = afs_Conn(&avc->f.fid, areq, 0);
 
 	    do {
-		tc = afs_Conn(&avc->f.fid, areq, 0);
-
 #ifdef AFS_64BIT_CLIENT
 	      restart:
 #endif
-		code = rxfs_storeInit(avc, tc, length, bytes, base,
+		code = rxfs_storeInit(avc, tc, base, bytes, length,
 					sync, &ops, &rock);
-		if ( code ) {
-		    osi_Panic(
-		    "afs_CacheStoreProc: rxfs_storeInit failed with %d", code);
-		}
+		if ( code )
+		    goto nocall;
 
 		code = afs_CacheStoreDCaches(avc, dclist, bytes, anewDV,
 			&doProcessFS, &OutStatus, nchunks, nomore, ops, rock);
 
+nocall:
 #ifdef AFS_64BIT_CLIENT
 		if (code == RXGEN_OPCODE && !afs_serverHasNo64Bit(tc)) {
 		    afs_serverSetNo64Bit(tc);
 		    goto restart;
 		}
+#else
+		continue;	/* dummy, label before block end won't work */
 #endif /* AFS_64BIT_CLIENT */
 	    } while (afs_Analyze
 		     (tc, code, &avc->f.fid, areq,
@@ -779,7 +769,7 @@ rxfs_fetchUfsWrite(void *r, struct osi_file *fP,
 
 afs_int32
 rxfs_fetchClose(void *r, struct vcache *avc, struct dcache * adc,
-					struct afs_FetchOutput *tsmall)
+					struct afs_FetchOutput *o)
 {
     afs_int32 code, code1 = 0;
     struct rxfs_fetchVariables *v = (struct rxfs_fetchVariables *)r;
@@ -788,14 +778,15 @@ rxfs_fetchClose(void *r, struct vcache *avc, struct dcache * adc,
 	return -1;
 
     RX_AFS_GUNLOCK();
-    code = EndRXAFS_FetchData(v->call, &tsmall->OutStatus,
-			      &tsmall->CallBack,
-			      &tsmall->tsync);
-    RX_AFS_GLOCK();
-
-    RX_AFS_GUNLOCK();
-    if (v->call)
-	code1 = rx_EndCall(v->call, code);
+#ifdef AFS_64BIT_CLIENT
+    if (!v->hasNo64bit)
+        code = EndRXAFS_FetchData64(v->call, &o->OutStatus, &o->CallBack,
+				&o->tsync);
+    else
+#endif
+        code = EndRXAFS_FetchData(v->call, &o->OutStatus, &o->CallBack,
+				&o->tsync);
+    code1 = rx_EndCall(v->call, code);
     RX_AFS_GLOCK();
     if (!code && code1)
 	code = code1;
@@ -812,6 +803,13 @@ rxfs_fetchDestroy(void **r, afs_int32 error)
     struct rxfs_fetchVariables *v = (struct rxfs_fetchVariables *)*r;
 
     *r = NULL;
+    if (v->call) {
+        RX_AFS_GUNLOCK();
+	code = rx_EndCall(v->call, error);
+        RX_AFS_GLOCK();
+	if (error)
+	    code = error;
+    }
     if (v->tbuffer)
 	osi_FreeLargeSpace(v->tbuffer);
     if (v->iov)
@@ -824,17 +822,28 @@ afs_int32
 rxfs_fetchMore(void *r, afs_uint32 *length, afs_uint32 *moredata)
 {
     afs_int32 code;
-    register struct rxfs_fetchVariables *v
-	    = (struct rxfs_fetchVariables *)r;
+    struct rxfs_fetchVariables *v = (struct rxfs_fetchVariables *)r;
 
+    /*
+     * The fetch protocol is extended for the AFS/DFS translator
+     * to allow multiple blocks of data, each with its own length,
+     * to be returned. As long as the top bit is set, there are more
+     * blocks expected.
+     *
+     * We do not do this for AFS file servers because they sometimes
+     * return large negative numbers as the transfer size.
+     */
     RX_AFS_GUNLOCK();
     code = rx_Read(v->call, (void *)length, sizeof(afs_int32));
-    *length = ntohl(*length);
     RX_AFS_GLOCK();
+    *length = ntohl(*length);
     if (code != sizeof(afs_int32)) {
 	code = rx_Error(v->call);
+	*moredata = 0;
 	return (code ? code : -1);	/* try to return code, not -1 */
     }
+    *moredata = *length & 0x80000000;
+    *length &= ~0x80000000;
     return 0;
 }
 
@@ -857,17 +866,14 @@ struct fetchOps rxfs_fetchMemOps = {
 };
 
 afs_int32
-rxfs_fetchInit(register struct afs_conn *tc, struct vcache *avc,afs_offs_t base,
-		afs_uint32 size, afs_uint32 *alength, struct dcache *adc,
+rxfs_fetchInit(struct afs_conn *tc, struct vcache *avc, afs_offs_t base,
+		afs_uint32 size, afs_uint32 *alength, afs_uint32 *moredata,
+		struct dcache *adc,
 		struct osi_file *fP, struct fetchOps **ops, void **rock)
 {
     struct rxfs_fetchVariables *v;
-    int code, code1;
-    afs_int32 length_hi, length, bytes;
-#ifdef AFS_64BIT_CLIENT
-    afs_size_t tsize;
-    afs_size_t lengthFound;     /* as returned from server */
-#endif /* AFS_64BIT_CLIENT */
+    int code = 0, code1;
+    afs_uint32 length_hi = 0, length, bytes;
 
     v = (struct rxfs_fetchVariables *) osi_AllocSmallSpace(sizeof(struct rxfs_fetchVariables));
     if (!v)
@@ -877,84 +883,110 @@ rxfs_fetchInit(register struct afs_conn *tc, struct vcache *avc,afs_offs_t base,
     RX_AFS_GUNLOCK();
     v->call = rx_NewCall(tc->id);
     RX_AFS_GLOCK();
-
+    if (v->call) {
 #ifdef AFS_64BIT_CLIENT
-    length_hi = code = 0;
-    if (!afs_serverHasNo64Bit(tc)) {
-	tsize = size;
-	RX_AFS_GUNLOCK();
-	code = StartRXAFS_FetchData64(v->call, (struct AFSFid *)&avc->f.fid.Fid,
-					base, tsize);
-	if (code != 0) {
+	afs_size_t length64;     /* as returned from server */
+	if (!afs_serverHasNo64Bit(tc)) {
+	    afs_uint64 llbytes = size;
+	    RX_AFS_GUNLOCK();
+	    code = StartRXAFS_FetchData64(v->call, (struct AFSFid *) &avc->f.fid.Fid,
+					       base, llbytes);
+	    if (code != 0) {
+		RX_AFS_GLOCK();
+		afs_Trace2(afs_iclSetp, CM_TRACE_FETCH64CODE,
+			       ICL_TYPE_POINTER, avc, ICL_TYPE_INT32, code);
+	    } else {
+		bytes = rx_Read(v->call, (char *)&length_hi, sizeof(afs_int32));
+		RX_AFS_GLOCK();
+		if (bytes == sizeof(afs_int32)) {
+		    length_hi = ntohl(length_hi);
+		} else {
+		    code = rx_Error(v->call);
+		    RX_AFS_GUNLOCK();
+		    code1 = rx_EndCall(v->call, code);
+		    RX_AFS_GLOCK();
+		    v->call = NULL;
+		}
+	    }
+	}
+	if (code == RXGEN_OPCODE || afs_serverHasNo64Bit(tc)) {
+	    if (base > 0x7FFFFFFF) {
+		code = EFBIG;
+	    } else {
+                afs_uint32 pos;
+		pos = base;
+		RX_AFS_GUNLOCK();
+		if (!v->call)
+		    v->call = rx_NewCall(tc->id);
+		code =
+		    StartRXAFS_FetchData(
+		    		v->call, (struct AFSFid*)&avc->f.fid.Fid,
+				pos, size);
+		RX_AFS_GLOCK();
+	    }
+	    afs_serverSetNo64Bit(tc);
+	}
+	if (!code) {
+	    RX_AFS_GUNLOCK();
+	    bytes = rx_Read(v->call, (char *)&length, sizeof(afs_int32));
 	    RX_AFS_GLOCK();
-	    afs_Trace2(afs_iclSetp, CM_TRACE_FETCH64CODE,
-                           ICL_TYPE_POINTER, avc, ICL_TYPE_INT32, code);
-	} else {
-	    bytes = rx_Read(v->call, (char *)&length_hi, sizeof(afs_int32));
+	    if (bytes == sizeof(afs_int32))
+		length = ntohl(length);
+	    else {
+		RX_AFS_GUNLOCK();
+		code = rx_Error(v->call);
+                code1 = rx_EndCall(v->call, code);
+		v->call = NULL;
+		RX_AFS_GLOCK();
+	    }
+	}
+	FillInt64(length64, length_hi, length);
+	afs_Trace3(afs_iclSetp, CM_TRACE_FETCH64LENG,
+		   ICL_TYPE_POINTER, avc, ICL_TYPE_INT32, code,
+		   ICL_TYPE_OFFSET,
+		   ICL_HANDLE_OFFSET(length64));
+	*alength = length64;
+#else /* AFS_64BIT_CLIENT */
+	RX_AFS_GUNLOCK();
+	code = StartRXAFS_FetchData(v->call, (struct AFSFid *)&avc->f.fid.Fid,
+				     base, size);
+	RX_AFS_GLOCK();
+	if (code == 0) {
+	    RX_AFS_GUNLOCK();
+	    bytes =
+		rx_Read(v->call, (char *)&length, sizeof(afs_int32));
 	    RX_AFS_GLOCK();
 	    if (bytes == sizeof(afs_int32)) {
-		length_hi = ntohl(length_hi);
+                *alength = ntohl(length);
 	    } else {
-		length_hi = 0;
 		code = rx_Error(v->call);
-		RX_AFS_GUNLOCK();
-		code1 = rx_EndCall(v->call, code);
-		RX_AFS_GLOCK();
+                code1 = rx_EndCall(v->call, code);
 		v->call = NULL;
 	    }
 	}
-    }
-    if (code == RXGEN_OPCODE || afs_serverHasNo64Bit(tc)) {
-	if (base > 0x7FFFFFFF) {
-	    code = EFBIG;
-	} else {
-	    afs_int32 pos;
-	    pos = base;
-	    RX_AFS_GUNLOCK();
-	    if (!v->call)
-		v->call = rx_NewCall(tc->id);
-	    code =
-		StartRXAFS_FetchData(v->call, (struct AFSFid *)&avc->f.fid.Fid,
-					pos, size);
-	    RX_AFS_GLOCK();
-	}
-	afs_serverSetNo64Bit(tc);
-    }
-    if (!code) {
-	RX_AFS_GUNLOCK();
-	bytes = rx_Read(v->call, (char *)&length, sizeof(afs_int32));
-	RX_AFS_GLOCK();
-	if (bytes == sizeof(afs_int32))
-	    length = ntohl(length);
-	else {
-	    code = rx_Error(v->call);
-	}
-    }
-    FillInt64(lengthFound, length_hi, length);
-    afs_Trace3(afs_iclSetp, CM_TRACE_FETCH64LENG,
-	       ICL_TYPE_POINTER, avc, ICL_TYPE_INT32, code,
-	       ICL_TYPE_OFFSET,
-	       ICL_HANDLE_OFFSET(lengthFound));
-#else /* AFS_64BIT_CLIENT */
-    RX_AFS_GUNLOCK();
-    code = StartRXAFS_FetchData(v->call, (struct AFSFid *)&avc->f.fid.Fid,
-				 base, size);
-    RX_AFS_GLOCK();
-    if (code == 0) {
-	RX_AFS_GUNLOCK();
-	bytes = rx_Read(v->call, (char *)&length, sizeof(afs_int32));
-	RX_AFS_GLOCK();
-	if (bytes == sizeof(afs_int32))
-	    length = ntohl(length);
-	else
-	    code = rx_Error(v->call);
-    }
 #endif /* AFS_64BIT_CLIENT */
+    } else
+	code = -1;
     if (code) {
 	osi_FreeSmallSpace(v);
         return code;
     }
-
+    /*
+     * The fetch protocol is extended for the AFS/DFS translator
+     * to allow multiple blocks of data, each with its own length,
+     * to be returned. As long as the top bit is set, there are more
+     * blocks expected.
+     *
+     * We do not do this for AFS file servers because they sometimes
+     * return large negative numbers as the transfer size.
+     *
+     * Also omit if length > 2^32, as bit 31 is part of the number then.
+     * Known to never be the case ifndef AFS_64BIT_CLIENT.
+     */
+    if (avc->f.states & CForeign && !length_hi) {
+	*moredata = length & 0x80000000;
+	length &= ~0x80000000;
+    }
     if (cacheDiskType == AFS_FCACHE_TYPE_UFS) {
 	v->tbuffer = osi_AllocLargeSpace(AFS_LRALLOCSIZ);
 	if (!v->tbuffer)
@@ -977,7 +1009,6 @@ rxfs_fetchInit(register struct afs_conn *tc, struct vcache *avc,afs_offs_t base,
 	*ops = (struct fetchOps *) &rxfs_fetchMemOps;
     }
     *rock = (void *)v;
-    *alength = length;
     return 0;
 }
 
@@ -988,7 +1019,7 @@ rxfs_fetchInit(register struct afs_conn *tc, struct vcache *avc,afs_offs_t base,
  *
  * \param tc Ptr to the Rx connection structure.
  * \param fP File descriptor for the cache file.
- * \param abase Base offset to fetch.
+ * \param base Base offset to fetch.
  * \param adc Ptr to the dcache entry for the file, write-locked.
  * \param avc Ptr to the vcache entry for the file.
  * \param size Amount of data that should be fetched.
@@ -997,19 +1028,17 @@ rxfs_fetchInit(register struct afs_conn *tc, struct vcache *avc,afs_offs_t base,
  * \note Environment: Nothing interesting.
  */
 int
-afs_CacheFetchProc(register struct afs_conn *tc,
-		    register struct osi_file *fP, afs_size_t abase,
-		    struct dcache *adc, struct vcache *avc,
-		    afs_int32 size,
+afs_CacheFetchProc(struct afs_conn *tc, struct osi_file *fP, afs_size_t base,
+		    struct dcache *adc, struct vcache *avc, afs_int32 size,
 		    struct afs_FetchOutput *tsmall)
 {
-    register afs_int32 code;
+    afs_int32 code;
     afs_uint32 length;
     afs_uint32 bytesread, byteswritten;
     struct fetchOps *ops = NULL;
     void *rock = NULL;
     int moredata = 0;
-    register int offset = 0;
+    int offset = 0;
 
     XSTATS_DECLS;
 #ifndef AFS_NOSTATS
@@ -1021,39 +1050,33 @@ afs_CacheFetchProc(register struct afs_conn *tc,
 
     XSTATS_START_TIME(AFS_STATS_FS_RPCIDX_FETCHDATA);
 
-    code = rxfs_fetchInit(tc, avc, abase, size, &length, adc, fP, &ops, &rock);
+    /*
+     * Locks held:
+     * avc->lock(R) if setLocks && !slowPass
+     * avc->lock(W) if !setLocks || slowPass
+     * adc->lock(W)
+     */
+    code = rxfs_fetchInit(
+		tc, avc, base, size, &length, &moredata, adc, fP, &ops, &rock);
 
 #ifndef AFS_NOSTATS
     osi_GetuTime(&xferStartTime);
 #endif /* AFS_NOSTATS */
 
-    adc->validPos = abase;
+    if (adc) {
+	adc->validPos = base;
+    }
 
     if ( !code ) do {
-	if (moredata) {
+	if ((avc->f.states & CForeign) && moredata && !length) {
 	    code = (*ops->more)(rock, &length, &moredata);
 	    if ( code )
 		break;
 	}
-	/*
-	 * The fetch protocol is extended for the AFS/DFS translator
-	 * to allow multiple blocks of data, each with its own length,
-	 * to be returned. As long as the top bit is set, there are more
-	 * blocks expected.
-	 *
-	 * We do not do this for AFS file servers because they sometimes
-	 * return large negative numbers as the transfer size.
-	 */
-	if (avc->f.states & CForeign) {
-	    moredata = length & 0x80000000;
-	    length &= ~0x80000000;
-	} else {
-	    moredata = 0;
-	}
 #ifndef AFS_NOSTATS
 	bytesToXfer += length;
 #endif /* AFS_NOSTATS */
-	while (length > 0) {
+	while (length) {
 #ifdef RX_KERNEL_TRACE
 	    afs_Trace1(afs_iclSetp, CM_TRACE_TIMESTAMP, ICL_TYPE_STRING,
 		       "before rx_Read");
@@ -1077,9 +1100,9 @@ afs_CacheFetchProc(register struct afs_conn *tc,
 	    if ( code )
 		break;
 	    offset += bytesread;
-	    abase += bytesread;
+	    base += bytesread;
 	    length -= bytesread;
-	    adc->validPos = abase;
+	    adc->validPos = base;
 	    if (afs_osi_Wakeup(&adc->validPos) == 0)
 		afs_Trace4(afs_iclSetp, CM_TRACE_DCACHEWAKE, ICL_TYPE_STRING,
 			   __FILE__, ICL_TYPE_INT32, __LINE__,
@@ -1090,10 +1113,11 @@ afs_CacheFetchProc(register struct afs_conn *tc,
     } while (moredata);
     if (!code)
 	code = (*ops->close)(rock, avc, adc, tsmall);
-    (*ops->destroy)(&rock, code);
+    if (ops)
+	(*ops->destroy)(&rock, code);
 
 #ifndef AFS_NOSTATS
-    FillStoreStats(code, AFS_STATS_FS_XFERIDX_FETCHDATA,&xferStartTime,
+    FillStoreStats(code, AFS_STATS_FS_XFERIDX_FETCHDATA, &xferStartTime,
 			bytesToXfer, bytesXferred);
 #endif
     XSTATS_END_TIME;
