@@ -18,8 +18,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_volume.c,v 1.31.2.10 2009/01/26 18:52:38 shadow Exp $");
 
 #include "afs/stds.h"
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
@@ -58,12 +56,7 @@ RCSID
 #endif /* vlserver error base define */
 
 /* Exported variables */
-#if defined(LINUX_USE_FH)
-struct fid volumeinfo_fh;     /* File handle for VolumeItems file */
-int volumeinfo_fh_type;
-#else
-ino_t volumeInode;            /* Inode for VolumeItems file */
-#endif
+afs_dcache_id_t volumeInode;	/* Inode for VolumeItems file */
 afs_rwlock_t afs_xvolume;	/** allocation lock for volumes */
 struct volume *afs_freeVolList;
 struct volume *afs_volumes[NVOLS];
@@ -164,11 +157,7 @@ afs_UFSGetVolSlot(void)
 	     * next chain
 	     */
 	    if (afs_FVIndex != tv->vtix) {
-#if defined(LINUX_USE_FH)
-		tfile = osi_UFSOpen_fh(&volumeinfo_fh, volumeinfo_fh_type);
-#else
-		tfile = osi_UFSOpen(volumeInode);
-#endif
+		tfile = osi_UFSOpen(&volumeInode);
 		code =
 		    afs_osi_Read(tfile, sizeof(struct fvolume) * tv->vtix,
 				 &staticFVolume, sizeof(struct fvolume));
@@ -185,11 +174,7 @@ afs_UFSGetVolSlot(void)
 	staticFVolume.dotdot = tv->dotdot;
 	staticFVolume.rootVnode = tv->rootVnode;
 	staticFVolume.rootUnique = tv->rootUnique;
-#if defined(LINUX_USE_FH)
-	tfile = osi_UFSOpen_fh(&volumeinfo_fh, volumeinfo_fh_type);
-#else
-	tfile = osi_UFSOpen(volumeInode);
-#endif
+	tfile = osi_UFSOpen(&volumeInode);
 	code =
 	    afs_osi_Write(tfile, sizeof(struct fvolume) * afs_FVIndex,
 			  &staticFVolume, sizeof(struct fvolume));
@@ -551,18 +536,14 @@ afs_SetupVolume(afs_int32 volid, char *aname, void *ve, struct cell *tcell,
 	tv = afs_GetVolSlot();
 	memset((char *)tv, 0, sizeof(struct volume));
 	tv->cell = tcell->cellNum;
-	RWLOCK_INIT(&tv->lock, "volume lock");
+	AFS_RWLOCK_INIT(&tv->lock, "volume lock");
 	tv->next = afs_volumes[i];	/* thread into list */
 	afs_volumes[i] = tv;
 	tv->volume = volid;
 	for (j = fvTable[FVHash(tv->cell, volid)]; j != 0; j = tf->next) {
 	    if (afs_FVIndex != j) {
 		struct osi_file *tfile;
-#if defined(LINUX_USE_FH)
-	        tfile = osi_UFSOpen_fh(&volumeinfo_fh, volumeinfo_fh_type);
-#else
-	        tfile = osi_UFSOpen(volumeInode);
-#endif
+	        tfile = osi_UFSOpen(&volumeInode);
 		err =
 		    afs_osi_Read(tfile, sizeof(struct fvolume) * j,
 				 &staticFVolume, sizeof(struct fvolume));
@@ -1075,7 +1056,8 @@ InstallUVolumeEntry(struct volume *av, struct uvldbentry *ve, int acell,
 		&& ts->addr) {
 		/* uuid, uniquifier, and portal are the same */
 	    } else {
-		afs_uint32 *addrp, nentries, code, unique;
+		afs_uint32 *addrp, code;
+		afs_int32 nentries, unique;
 		bulkaddrs addrs;
 		ListAddrByAttributes attrs;
 		afsUUID uuid;
