@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/budb/server.c,v 1.16.2.14 2009/03/16 13:41:34 shadow Exp $");
 
 #include <fcntl.h>
 #include <sys/stat.h>
@@ -47,7 +45,7 @@ RCSID
 #include "budb_errs.h"
 #include "database.h"
 #include "error_macros.h"
-#include "budb_prototypes.h"
+#include "budb_internal.h"
 #include "globals.h"
 #include "afs/audit.h"
 
@@ -177,6 +175,8 @@ initializeArgHandler(void)
     cmd_AddParm(cptr, "-rxbind", CMD_FLAG, CMD_OPTIONAL,
 		"bind the Rx socket (primary interface only)");
 
+    cmd_AddParm(cptr, "-audit-interface", CMD_SINGLE, CMD_OPTIONAL,
+		"audit interface (file or sysvmq)");
 }
 
 int
@@ -228,11 +228,7 @@ argHandler(struct cmd_syndesc *as, void *arock)
     else
 	ubik_nBuffers = 0;
 
-    if (as->parms[7].items != 0) {
-	char *fileName = as->parms[7].items->data;
-
-        osi_audit_file(fileName);
-    }
+    /* param 7 (-auditlog) handled below */
 
     /* user provided the number of threads    */
     if (as->parms[8].items != 0) {
@@ -254,6 +250,25 @@ argHandler(struct cmd_syndesc *as, void *arock)
 	rxBind = 1;
     }
 
+    /* -audit-interface */
+    if (as->parms[10].items != 0) {
+	char *interface = as->parms[10].items->data;
+
+	if (osi_audit_interface(interface)) {
+	    printf("Invalid audit interface '%s'\n", interface);
+	    BUDB_EXIT(-1);
+	}
+    }
+
+    /* -auditlog */
+    /* needs to be after -audit-interface, so we osi_audit_interface
+     * before we osi_audit_file */
+    if (as->parms[7].items != 0) {
+	char *fileName = as->parms[7].items->data;
+
+        osi_audit_file(fileName);
+    }
+
     return 0;
 }
 
