@@ -30,8 +30,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/des/key_sched.c,v 1.11 2005/08/18 04:55:00 shadow Exp $");
 
 #include <mit-cpyright.h>
 #include "des_internal.h"
@@ -44,7 +42,7 @@ RCSID
 typedef char key[64];
 
 /* the following are really void but cc86 doesnt allow it */
-static int make_key_sched();
+static int make_key_sched(key Key, des_key_schedule Schedule);
 
 #ifdef AFS_DUX40_ENV
 #pragma weak des_key_sched = afs_des_key_sched
