@@ -18,8 +18,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/rx/rx_pthread.c,v 1.24.4.9 2009/01/28 22:33:28 shadow Exp $");
 
 #include <sys/types.h>
 #include <errno.h>
@@ -33,6 +31,7 @@ RCSID
 # include <net/if.h>
 # include <sys/ioctl.h>
 # include <sys/time.h>
+# include <unistd.h>
 #endif
 #include <sys/stat.h>
 #include <rx/rx.h>
@@ -97,11 +96,11 @@ rxi_InitializeThreadSupport(void)
 static void *
 server_entry(void *argp)
 {
-    void (*server_proc) () = (void (*)())argp;
-    server_proc();
+    void (*server_proc) (void *) = (void (*)(void *))argp;
+    server_proc(NULL);
     dpf(("rx_pthread.c: server_entry: Server proc returned unexpectedly\n"));
     exit(1);
-    return (void *)0;
+    return NULL;
 }
 
 /*
@@ -142,7 +141,6 @@ rxi_StartServerProc(void *(*proc) (void *), int stacksize)
 static void *
 event_handler(void *argp)
 {
-    struct clock rx_pthread_last_event_wait_time = { 0, 0 };
     unsigned long rx_pthread_n_event_expired = 0;
     unsigned long rx_pthread_n_event_waits = 0;
     long rx_pthread_n_event_woken = 0;
@@ -192,6 +190,7 @@ event_handler(void *argp)
 #endif
 	rx_pthread_event_rescheduled = 0;
     }
+    return NULL;
 }
 
 
@@ -272,6 +271,7 @@ rx_ListenerProc(void *argp)
 	/* assert(sock != OSI_NULLSOCKET); */
     }
     /* not reached */
+    return NULL;
 }
 
 /* This is the server process request loop. The server process loop
@@ -319,6 +319,7 @@ rx_ServerProc(void * dummy)
 	/* assert(newcall != NULL); */
     }
     /* not reached */
+    return NULL;
 }
 
 /*
@@ -438,12 +439,19 @@ rxi_Sendmsg(osi_socket socket, struct msghdr *msg_p, int flags)
 #endif
 	dpf(("rxi_sendmsg failed, error %d\n", errno));
 	fflush(stdout);
+#ifndef AFS_NT40_ENV
+        if (errno > 0)
+          return -errno;
+#else
+            if (WSAGetLastError() > 0)
+              return -WSAGetLastError();
+#endif
 	return -1;
     }
     return 0;
 }
 
-struct rx_ts_info_t * rx_ts_info_init() {
+struct rx_ts_info_t * rx_ts_info_init(void) {
     struct rx_ts_info_t * rx_ts_info;
     rx_ts_info = (rx_ts_info_t *) malloc(sizeof(rx_ts_info_t));
     assert(rx_ts_info != NULL && pthread_setspecific(rx_ts_info_key, rx_ts_info) == 0);
