@@ -29,14 +29,12 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/rx/xdr_arrayn.c,v 1.10.6.2 2009/01/28 22:33:28 shadow Exp $");
 
 #if defined(AFS_OBSD44_ENV) && defined(KERNEL) && !defined(UKERNEL)
 /* XXX osi_alloc, please find and fix */
 #include "osi_machdep.h"
 #endif
- 
+
 #if !defined(NeXT)
 
 /*
@@ -61,6 +59,7 @@ RCSID
 #endif
 #else
 #include <stdio.h>
+#include <string.h>
 #endif
 #include "xdr.h"
 
