@@ -30,6 +30,7 @@ extern pthread_mutex_t host_glock_mutex;
     assert(pthread_mutex_lock(&host_glock_mutex) == 0)
 #define H_UNLOCK \
     assert(pthread_mutex_unlock(&host_glock_mutex) == 0)
+extern pthread_key_t viced_uclient_key;
 #else /* AFS_PTHREAD_ENV */
 #define H_LOCK
 #define H_UNLOCK
@@ -56,6 +57,7 @@ struct Identity {
 struct AddrPort  {
     afs_uint32 addr;		/* in network byte order */
     afs_uint16 port;		/* in network byte order */
+    afs_int16  valid;
 };
 
 struct Interface {
@@ -108,13 +110,18 @@ struct host {
 /* * Don't zero the index, lock or condition varialbles */
 #define HOST_TO_ZERO(H) (int)(((char *)(&((H)->index))-(char *)(H)))
 
-struct h_hashChain {
+struct h_AddrHashChain {
     struct host *hostPtr;
-    struct h_hashChain *next;
+    struct h_AddrHashChain *next;
     afs_uint32 addr;
     afs_uint16 port;
 };
 
+struct h_UuidHashChain {
+    struct host *hostPtr;
+    struct h_UuidHashChain *next;
+};
+
 struct client {
     struct client *next;	/* next client entry for host */
     struct host *host;		/* ptr to parent host entry */
@@ -217,37 +224,41 @@ extern int MultiBreakCallBackAlternateAddress_r(struct host *host,
 				     struct AFSCBFids *afidp);
 extern int DumpCallBackState(void);
 extern int PrintCallBackStats(void);
-extern int ShutDown(void);
+extern void *ShutDown(void *);
 extern void ShutDownAndCore(int dopanic);
 
 extern struct host *h_Alloc(register struct rx_connection *r_con);
 extern struct host *h_Alloc_r(register struct rx_connection *r_con);
-extern struct host *h_Lookup_r(afs_uint32 hostaddr, afs_uint16 hport,
-			       int *heldp);
-extern void   hashInsert_r(afs_uint32 addr, afs_uint16 port, 
-			   struct host* host);
+extern int h_Lookup_r(afs_uint32 hostaddr, afs_uint16 hport,
+		      int *heldp, struct host **hostp);
 extern struct host *h_LookupUuid_r(afsUUID * uuidp);
-extern void h_Enumerate(int (*proc) (), char *param);
-extern void h_Enumerate_r(int (*proc) (), struct host *enumstart, char *param);
+extern void h_Enumerate(int (*proc) (struct host *, int, void *), void *param);
+extern void h_Enumerate_r(int (*proc) (struct host *, int, void *), struct host *enumstart, void *param);
 extern struct host *h_GetHost_r(struct rx_connection *tcon);
 extern struct client *h_FindClient_r(struct rx_connection *tcon);
 extern int h_ReleaseClient_r(struct client *client);
 extern struct client *h_ID2Client(afs_int32 vid);
 extern int GetClient(struct rx_connection *tcon, struct client **cp);
 extern int PutClient(struct client **cp);
-extern void h_PrintStats();
-extern void h_PrintClients();
-extern void h_GetWorkStats();
+extern void h_PrintStats(void);
+extern void h_PrintClients(void);
+extern void h_GetWorkStats(int *, int *, int *, afs_int32);
 extern void h_flushhostcps(register afs_uint32 hostaddr,
 			   register afs_uint16 hport);
 extern void h_GetHostNetStats(afs_int32 * a_numHostsP, afs_int32 * a_sameNetOrSubnetP,
 		  afs_int32 * a_diffSubnetP, afs_int32 * a_diffNetworkP);
 extern int h_NBLock_r(register struct host *host);
-extern void h_DumpHosts();
-extern void h_InitHostPackage();
-extern void h_CheckHosts();
-struct Interface *MultiVerifyInterface_r();
+extern void h_DumpHosts(void);
+extern void h_InitHostPackage(void);
+extern void h_CheckHosts(void );
 extern int initInterfaceAddr_r(struct host *host, struct interfaceAddr *interf);
+extern void h_AddHostToAddrHashTable_r(afs_uint32 addr, afs_uint16 port, struct host * host);
+extern void h_AddHostToUuidHashTable_r(afsUUID * uuid, struct host * host);
+extern int h_DeleteHostFromAddrHashTable_r(afs_uint32 addr, afs_uint16 port, struct host *host);
+extern int initInterfaceAddr_r(struct host *host, struct interfaceAddr *interf);
+extern int addInterfaceAddr_r(struct host *host, afs_uint32 addr, afs_uint16 port);
+extern int removeInterfaceAddr_r(struct host *host, afs_uint32 addr, afs_uint16 port);
+
 
 #ifdef AFS_DEMAND_ATTACH_FS
 /*
@@ -285,5 +296,5 @@ struct host *(hosttableptrs[h_MAXHOSTTABLES]);	/* Used by h_itoh */
 #define RESETDONE			0x40	/* callback reset done */
 #define HFE_LATER                       0x80	/* host has FE_LATER callbacks */
 #define HERRORTRANS                    0x100	/* do error translation */
-
+#define HWHO_INPROGRESS                0x200    /* set when WhoAreYou running */
 #endif /* _AFS_VICED_HOST_H */
