@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/vol/nuke.c,v 1.17.2.2 2009/03/16 13:11:55 shadow Exp $");
 
 #include <rx/xdr.h>
 #include <afs/afsint.h>
@@ -29,6 +27,10 @@ RCSID
 #else
 #include <strings.h>
 #endif
+#ifndef AFS_NT40_ENV
+#include <unistd.h>
+#endif
+
 #include <afs/afsutil.h>
     
 #include <afs/assert.h>
@@ -73,8 +75,9 @@ struct ilist {
  * Note that ainfo->u.param[0] is always the volume ID, for any vice inode.
  */
 static int
-NukeProc(struct ViceInodeInfo *ainfo, afs_int32 avolid, struct ilist **allInodes)
+NukeProc(struct ViceInodeInfo *ainfo, afs_uint32 avolid, void *arock)
 {
+    struct ilist **allInodes = (struct ilist **)arock;
     struct ilist *ti;
     register afs_int32 i;
 
