@@ -19,8 +19,6 @@
 #include <afs/param.h>
 #define MAXINT     (~(1<<((sizeof(int)*8)-1)))
 
-RCSID
-    ("$Header: /cvs/openafs/src/vol/vnode.c,v 1.27.2.8 2009/03/16 13:11:55 shadow Exp $");
 
 #include <errno.h>
 #include <stdio.h>
@@ -1584,7 +1582,9 @@ VInvalidateVnodesByVolume_r(Volume * vp,
      * Traverse the volume's vnode list.  Pull all the ihandles out into a 
      * thread-private array for later asynchronous processing.
      */
- restart_traversal:
+#ifdef AFS_DEMAND_ATTACH_FS
+restart_traversal:
+#endif
     for (queue_Scan(&vp->vnode_list, vnp, nvnp, Vnode)) {
 	if (vnp->handle != NULL) {
 	    if (i == vec_len) {
@@ -1659,7 +1659,6 @@ VCloseVnodeFiles_r(Volume * vp)
 
     for (i = 0; i < vec_len; i++) {
 	IH_REALLYCLOSE(ih_vec[i]);
-        IH_RELEASE(ih_vec[i]);
     }
 
     free(ih_vec);
